==> kwave_0.8.5.orig.tar.bz2: kwave-0.8.5/cmake/KwavePackageMessages.cmake <==
#############################################################################
##    Kwave                - cmake/KwavePackageMessages.cmake
##                           -------------------
##    begin                : Sun May 20 2007
##    copyright            : (C) 2007 by Thomas Eschenbacher
##    email                : Thomas.Eschenbacher@gmx.de
#############################################################################
#
#############################################################################
##                                                                          #
##    This program is free software; you can redistribute it and/or modify  #
##    it under the terms of the GNU General Public License as published by  #
##    the Free Software Foundation; either version 2 of the License, or     #
##    (at your option) any later version.                                   #
##                                                                          #
#############################################################################

FIND_PACKAGE(RequiredProgram REQUIRED)

FIND_REQUIRED_PROGRAM(XGETTEXT_EXECUTABLE xgettext)
FIND_REQUIRED_PROGRAM(FIND_EXECUTABLE find)
SET(KDE_POT_FILE ${KDE4_INCLUDE_DIR}/kde.pot)

ADD_CUSTOM_TARGET(package-messages
    COMMAND $(MAKE) all # first make sure all generated source exists
    COMMAND ${RM_EXECUTABLE} -f po/*.gmo
    COMMAND ${XGETTEXT_EXECUTABLE} -C
        -ki18n -ki18np -ki18nc -ki18ncp -ktr2i18n -kI18N_NOOP -kki18nc -kki18n
        # -x ${KDE_POT_FILE}
        `${FIND_EXECUTABLE} ${CMAKE_CURRENT_SOURCE_DIR} -name \\*.h -o -name \\*.cpp`
        `${FIND_EXECUTABLE} ${CMAKE_CURRENT_BINARY_DIR} -name \\*.h -o -name \\*.cpp`
        -o ${CMAKE_SOURCE_DIR}/po/kwave.pot
    COMMAND $(MAKE) translations
    DEPENDS ${CMAKE_CURRENT_SOURCE_DIR}/kwave/menus.config
)

#############################################################################
#############################################################################

==> kwave_0.8.11-1.orig.tar.bz2: kwave-0.8.11/cmake/KwavePackageMessages.cmake <==
#############################################################################
##    Kwave                - cmake/KwavePackageMessages.cmake
##                           -------------------
##    begin                : Sun May 20 2007
##    copyright            : (C) 2007 by Thomas Eschenbacher
##    email                : Thomas.Eschenbacher@gmx.de
#############################################################################
#
#############################################################################
##                                                                          #
##    This program is free software; you can redistribute it and/or modify  #
##    it under the terms of the GNU General Public License as published by  #
##    the Free Software Foundation; either version 2 of the License, or     #
##    (at your option) any later version.                                   #
##                                                                          #
#############################################################################

FIND_PACKAGE(RequiredProgram REQUIRED)

FIND_REQUIRED_PROGRAM(XGETTEXT_EXECUTABLE xgettext)
FIND_REQUIRED_PROGRAM(FIND_EXECUTABLE find)
SET(KDE_POT_FILE ${KDE4_INCLUDE_DIR}/kde.pot)

ADD_CUSTOM_TARGET(package-messages
    COMMAND $(MAKE) all # first make sure all generated source exists
    COMMAND ${RM_EXECUTABLE} -f po/*.gmo
    COMMAND ${XGETTEXT_EXECUTABLE} --from-code=UTF-8 -C --kde
        -ci18n -ki18n:1 -ki18nc:1c,2 -ki18np:1,2 -ki18ncp:1c,2,3 -ktr2i18n:1
        -kI18N_NOOP:1 -kI18N_NOOP2:1c,2 -kaliasLocale -kki18n:1 -kki18nc:1c,2
        -kki18np:1,2 -kki18ncp:1c,2,3
        -D ${CMAKE_CURRENT_SOURCE_DIR}
        -D ${CMAKE_CURRENT_BINARY_DIR}
        `cd ${CMAKE_CURRENT_SOURCE_DIR} && ${FIND_EXECUTABLE} . -name \\*.h -o -name \\*.cpp`
        `cd ${CMAKE_CURRENT_BINARY_DIR} && ${FIND_EXECUTABLE} . -name \\*.h -o -name \\*.cpp`
        -o ${CMAKE_SOURCE_DIR}/po/kwave.pot
    COMMAND $(MAKE) translations
    DEPENDS ${CMAKE_CURRENT_SOURCE_DIR}/kwave/menus.config
)

#############################################################################
#############################################################################
